@@ -4,6 +4,7 @@
 
 #include <libnf.h>
 #include <arpa/inet.h>
+#include <sys/socket.h>
 #include <unistd.h>
 
 #define FILENAME "./test-file.tmp"
@@ -28,14 +29,21 @@ int main(int argc, char **argv) {
 
     int print = 1;
     int filter = 1;
+    int fget = 1;
     char *filename = FILENAME;
     char c;
 
-	while ((c = getopt (argc, argv, "pFf:1:2:")) != -1) {
+	while ((c = getopt (argc, argv, "pPFGf:1:2:")) != -1) {
 		switch (c) {
 			case 'p':
 				print = 0;
 				break;
+			case 'P':
+				print = 0;
+				break;
+			case 'G':
+				fget = 0;
+				break;
 			case 'F':
 				filter = 0;
 				break;
@@ -50,8 +58,9 @@ int main(int argc, char **argv) {
 				break;
 			case '?':
 				printf("Usage: %s [ -p ] [ -f <output file name> ] [ -1 <filter1> ] [ -2 <filter2> ]\n", argv[0]);
-				printf(" -p : do not print records to stdout\n");
+				printf(" -P : do not print records to stdout\n");
 				printf(" -F : do not use filters\n");
+				printf(" -G : do not use lng_rec_fget\n");
 				exit(1);
 		}
 	}
@@ -77,9 +86,11 @@ int main(int argc, char **argv) {
 
 	while (lnf_read(filep, recp) != LNF_EOF) {
 
-		lnf_rec_fget(recp, LNF_FLD_BREC1, &brec);
-		lnf_rec_fget(recp, LNF_FLD_INPUT, &input);
-		lnf_rec_fget(recp, LNF_FLD_OUTPUT, &output);
+		if (fget) {
+			lnf_rec_fget(recp, LNF_FLD_BREC1, &brec);
+			lnf_rec_fget(recp, LNF_FLD_INPUT, &input);
+			lnf_rec_fget(recp, LNF_FLD_OUTPUT, &output);
+		}
 		i++;
 
 		match1 = 0;
